@@ -45,40 +45,40 @@ import numpy.ma as ma
 import scipy.interpolate
 import scipy.stats.mstats
 
+import iris._lazy_data
 from iris.analysis._area_weighted import AreaWeightedRegridder
 from iris.analysis._interpolation import (
     EXTRAPOLATION_MODES,
     RectilinearInterpolator,
 )
-from iris.analysis._regrid import RectilinearRegridder, CurvilinearRegridder
+from iris.analysis._regrid import CurvilinearRegridder, RectilinearRegridder
 import iris.coords
 from iris.exceptions import LazyAggregatorError
-import iris._lazy_data
 
 __all__ = (
+    "Aggregator",
+    "AreaWeighted",
     "COUNT",
     "GMEAN",
     "HMEAN",
+    "Linear",
     "MAX",
     "MEAN",
     "MEDIAN",
     "MIN",
+    "Nearest",
     "PEAK",
     "PERCENTILE",
     "PROPORTION",
+    "PointInCell",
     "RMS",
     "STD_DEV",
     "SUM",
+    "UnstructuredNearest",
     "VARIANCE",
     "WPERCENTILE",
-    "Aggregator",
     "WeightedAggregator",
     "clear_phenomenon_identity",
-    "Linear",
-    "AreaWeighted",
-    "Nearest",
-    "UnstructuredNearest",
-    "PointInCell",
 )
 
 
@@ -1394,7 +1394,7 @@ def _lazy_rms(array, axis, **kwargs):
     # all. Thus trying to use this aggregator with weights will currently
     # raise an error in dask due to the unexpected keyword `weights`,
     # rather than silently returning the wrong answer.
-    return da.sqrt(da.mean(array ** 2, axis=axis, **kwargs))
+    return da.sqrt(da.mean(array**2, axis=axis, **kwargs))
 
 
 @_build_dask_mdtol_function
@@ -1454,7 +1454,7 @@ def _peak(array, **kwargs):
     slices[-1] = endslice
     slices = tuple(slices)  # Numpy>=1.16 : index with tuple, *not* list.
 
-    if isinstance(array.dtype, np.float):
+    if isinstance(array.dtype, np.float64):
         data = array[slices]
     else:
         # Cast non-float data type.
@@ -2170,15 +2170,20 @@ class _Groupby:
     def _compute_shared_coords(self):
         """Create the new shared coordinates given the group slices."""
 
+        groupby_indices = []
         groupby_bounds = []
 
-        # Iterate over the ordered dictionary in order to construct
-        # a list of tuple group boundary indexes.
+        # Iterate over the ordered dictionary in order to construct a list of
+        # tuple group indices, and a list of the respective bounds of those
+        # indices.
         for key_slice in self._slices_by_key.values():
             if isinstance(key_slice, tuple):
-                groupby_bounds.append((key_slice[0], key_slice[-1]))
+                indices = key_slice
             else:
-                groupby_bounds.append((key_slice.start, key_slice.stop - 1))
+                indices = tuple(range(*key_slice.indices(self._stop)))
+
+            groupby_indices.append(indices)
+            groupby_bounds.append((indices[0], indices[-1]))
 
         # Create new shared bounded coordinates.
         for coord, dim in self._shared_coords:
@@ -2197,15 +2202,9 @@ class _Groupby:
                         new_shape += shape[:-1]
                     work_arr = work_arr.reshape(work_shape)
 
-                    for key_slice in self._slices_by_key.values():
-                        if isinstance(key_slice, slice):
-                            indices = key_slice.indices(
-                                coord.points.shape[dim]
-                            )
-                            key_slice = range(*indices)
-
+                    for indices in groupby_indices:
                         for arr in work_arr:
-                            new_points.append("|".join(arr.take(key_slice)))
+                            new_points.append("|".join(arr.take(indices)))
 
                     # Reinstate flattened dimensions. Aggregated dim now leads.
                     new_points = np.array(new_points).reshape(new_shape)
@@ -2220,48 +2219,54 @@ class _Groupby:
                     raise ValueError(msg)
             else:
                 new_bounds = []
+                if coord.has_bounds():
+                    # Derive new coord's bounds from bounds.
+                    item = coord.bounds
+                    maxmin_axis = (dim, -1)
+                    first_choices = coord.bounds.take(0, -1)
+                    last_choices = coord.bounds.take(1, -1)
+                else:
+                    # Derive new coord's bounds from points.
+                    item = coord.points
+                    maxmin_axis = dim
+                    first_choices = last_choices = coord.points
+
+                # Check whether item is monotonic along the dimension of interest.
+                deltas = np.diff(item, 1, dim)
+                monotonic = np.all(deltas >= 0) or np.all(deltas <= 0)
 
                 # Construct list of coordinate group boundary pairs.
-                for start, stop in groupby_bounds:
-                    if coord.has_bounds():
-                        # Collapse group bounds into bounds.
+                if monotonic:
+                    # Use first and last bound or point for new bounds.
+                    for start, stop in groupby_bounds:
                         if (
                             getattr(coord, "circular", False)
-                            and (stop + 1) == coord.shape[dim]
+                            and (stop + 1) == self._stop
                         ):
                             new_bounds.append(
                                 [
-                                    coord.bounds.take(start, dim).take(0, -1),
-                                    coord.bounds.take(0, dim).take(0, -1)
+                                    first_choices.take(start, dim),
+                                    first_choices.take(0, dim)
                                     + coord.units.modulus,
                                 ]
                             )
                         else:
                             new_bounds.append(
                                 [
-                                    coord.bounds.take(start, dim).take(0, -1),
-                                    coord.bounds.take(stop, dim).take(1, -1),
-                                ]
-                            )
-                    else:
-                        # Collapse group points into bounds.
-                        if getattr(coord, "circular", False) and (
-                            stop + 1
-                        ) == len(coord.points):
-                            new_bounds.append(
-                                [
-                                    coord.points.take(start, dim),
-                                    coord.points.take(0, dim)
-                                    + coord.units.modulus,
-                                ]
-                            )
-                        else:
-                            new_bounds.append(
-                                [
-                                    coord.points.take(start, dim),
-                                    coord.points.take(stop, dim),
+                                    first_choices.take(start, dim),
+                                    last_choices.take(stop, dim),
                                 ]
                             )
+                else:
+                    # Use min and max bound or point for new bounds.
+                    for indices in groupby_indices:
+                        item_slice = item.take(indices, dim)
+                        new_bounds.append(
+                            [
+                                item_slice.min(axis=maxmin_axis),
+                                item_slice.max(axis=maxmin_axis),
+                            ]
+                        )
 
                 # Bounds needs to be an array with the length 2 start-stop
                 # dimension last, and the aggregated dimension back in its
@@ -2686,14 +2691,6 @@ class UnstructuredNearest:
     .. Note::
         Currently only supports regridding, not interpolation.
 
-    .. Note::
-          This scheme performs essentially the same job as
-          :class:`iris.experimental.regrid.ProjectedUnstructuredNearest`.
-          That scheme is faster, but only works well on data in a limited
-          region of the globe, covered by a specified projection.
-          This approach is more rigorously correct and can be applied to global
-          datasets.
-
     """
 
     # Note: the argument requirements are simply those of the underlying
@@ -2764,6 +2761,9 @@ class PointInCell:
     This class describes the point-in-cell regridding scheme for use
     typically with :meth:`iris.cube.Cube.regrid()`.
 
+    Each result datapoint is an average over all source points that fall inside
+    that (bounded) target cell.
+
     The PointInCell regridder can regrid data from a source grid of any
     dimensionality and in any coordinate system.
     The location of each source point is specified by X and Y coordinates
@@ -2781,8 +2781,12 @@ class PointInCell:
 
     def __init__(self, weights=None):
         """
-        Point-in-cell regridding scheme suitable for regridding over one
-        or more orthogonal coordinates.
+        Point-in-cell regridding scheme suitable for regridding from a source
+        cube with X and Y coordinates all on the same dimensions, to a target
+        cube with bounded X and Y coordinates on separate X and Y dimensions.
+
+        Each result datapoint is an average over all source points that fall
+        inside that (bounded) target cell.
 
         Optional Args:
 
