@@ -26,7 +26,7 @@ import iris.coord_systems
 import iris.coords
 from iris.util import delta
 
-__all__ = ["cube_delta", "differentiate", "curl"]
+__all__ = ["cube_delta", "curl", "differentiate"]
 
 
 def _construct_delta_coord(coord):
@@ -629,14 +629,10 @@ def curl(i_cube, j_cube, k_cube=None):
         #    (d/dtheta (i_cube * sin(lat)) - d_j_cube_dphi)
         # phi_cmpt = 1/r * ( d/dr (r * j_cube) - d_k_cube_dtheta)
         # theta_cmpt = 1/r * ( 1/cos(lat) * d_k_cube_dphi - d/dr (r * i_cube)
-        if (
-            y_coord.name()
-            not in [
-                "latitude",
-                "grid_latitude",
-            ]
-            or x_coord.name() not in ["longitude", "grid_longitude"]
-        ):
+        if y_coord.name() not in [
+            "latitude",
+            "grid_latitude",
+        ] or x_coord.name() not in ["longitude", "grid_longitude"]:
             raise ValueError(
                 "Expecting latitude as the y coord and "
                 "longitude as the x coord for spherical curl."
