@@ -160,27 +160,37 @@ def _build_lat_lon_for_NAME_timeseries(column_headings):
     the provided column_headings dictionary.
 
     """
-    pattern = re.compile(r"\-?[0-9]*\.[0-9]*")
-    new_Xlocation_column_header = []
-    for t in column_headings["X"]:
-        if "Lat-Long" in t:
-            matches = pattern.search(t)
-            new_Xlocation_column_header.append(float(matches.group(0)))
-        else:
-            new_Xlocation_column_header.append(t)
-    column_headings["X"] = new_Xlocation_column_header
+    # Pattern to match a number
+    pattern = re.compile(
+        r"""
+        [-+]?          # Optional sign
+        (?:
+            \d+\.\d*   # Float: integral part required
+        |
+            \d*\.\d+   # Float: fractional part required
+        |
+            \d+        # Integer
+        )
+        (?![0-9.])     # Not followed by a numeric character
+        """,
+        re.VERBOSE,
+    )
+
+    # Extract numbers from the X and Y column headings, which are currently
+    # strings of the form "X = -1.9 Lat-Long"
+    for key in ("X", "Y"):
+        new_headings = []
+        for heading in column_headings[key]:
+            match = pattern.search(heading)
+            if match and "Lat-Long" in heading:
+                new_headings.append(float(match.group(0)))
+            else:
+                new_headings.append(heading)
+        column_headings[key] = new_headings
+
     lon = NAMECoord(
         name="longitude", dimension=None, values=column_headings["X"]
     )
-
-    new_Ylocation_column_header = []
-    for t in column_headings["Y"]:
-        if "Lat-Long" in t:
-            matches = pattern.search(t)
-            new_Ylocation_column_header.append(float(matches.group(0)))
-        else:
-            new_Ylocation_column_header.append(t)
-    column_headings["Y"] = new_Ylocation_column_header
     lat = NAMECoord(
         name="latitude", dimension=None, values=column_headings["Y"]
     )
@@ -387,6 +397,7 @@ def _cf_height_from_name(z_coord, lower_bound=None, upper_bound=None):
         standard_name=standard_name,
         long_name=long_name,
         bounds=bounds,
+        attributes={"positive": "up"},
     )
 
     return coord
@@ -478,7 +489,7 @@ def _generate_cubes(
                 coord_units = _parse_units("FL")
             if coord.name == "time":
                 coord_units = time_unit
-                pts = np.float_(time_unit.date2num(coord.values))
+                pts = time_unit.date2num(coord.values).astype(float)
 
             if coord.dimension is not None:
                 if coord.name == "longitude":
@@ -505,7 +516,7 @@ def _generate_cubes(
                 ):
                     dt = coord.values - field_headings["Av or Int period"]
                     bnds = time_unit.date2num(np.vstack((dt, coord.values)).T)
-                    icoord.bounds = np.float_(bnds)
+                    icoord.bounds = bnds.astype(float)
                 else:
                     icoord.guess_bounds()
                 cube.add_dim_coord(icoord, coord.dimension)
@@ -522,7 +533,7 @@ def _generate_cubes(
                 ):
                     dt = coord.values - field_headings["Av or Int period"]
                     bnds = time_unit.date2num(np.vstack((dt, coord.values)).T)
-                    icoord.bounds = np.float_(bnds[i, :])
+                    icoord.bounds = bnds[i, :].astype(float)
                 cube.add_aux_coord(icoord)
 
         # Headings/column headings which are encoded elsewhere.
@@ -1250,7 +1261,7 @@ def load_NAMEIII_trajectory(filename):
 
         long_name = units = None
         if isinstance(values[0], datetime.datetime):
-            values = np.float_(time_unit.date2num(values))
+            values = time_unit.date2num(values).astype(float)
             units = time_unit
             if name == "Time":
                 name = "time"
