@@ -18,26 +18,25 @@ import struct
 import warnings
 
 import cf_units
-import numpy as np
-import numpy.ma as ma
 import cftime
-
 import dask
 import dask.array as da
+import numpy as np
+import numpy.ma as ma
 
 from iris._lazy_data import as_concrete_data, as_lazy_data, is_lazy_data
 import iris.config
-import iris.fileformats.pp_load_rules
-from iris.fileformats.pp_save_rules import verify
+import iris.coord_systems
 
 # NOTE: this is for backwards-compatitibility *ONLY*
 # We could simply remove it for v2.0 ?
-from iris.fileformats._pp_lbproc_pairs import (  # noqa
-    LBPROC_PAIRS,
+from iris.fileformats._pp_lbproc_pairs import (  # noqa: F401
     LBPROC_MAP as lbproc_map,
 )
+from iris.fileformats._pp_lbproc_pairs import LBPROC_PAIRS  # noqa: F401
+import iris.fileformats.pp_load_rules
+from iris.fileformats.pp_save_rules import verify
 import iris.fileformats.rules
-import iris.coord_systems
 
 try:
     import mo_pack
@@ -46,16 +45,16 @@ except ImportError:
 
 
 __all__ = [
-    "load",
-    "save",
-    "load_cubes",
-    "PPField",
-    "as_fields",
-    "load_pairs_from_fields",
-    "save_pairs_from_cube",
-    "save_fields",
-    "STASH",
     "EARTH_RADIUS",
+    "PPField",
+    "STASH",
+    "as_fields",
+    "load",
+    "load_cubes",
+    "load_pairs_from_fields",
+    "save",
+    "save_fields",
+    "save_pairs_from_cube",
 ]
 
 
@@ -746,7 +745,7 @@ def _data_bytes_to_shaped_array(
             # However, we still mask any MDI values in the array (below).
             pass
         else:
-            land_mask = mask.data.astype(np.bool)
+            land_mask = mask.data.astype(np.bool_)
             sea_mask = ~land_mask
             new_data = np.ma.masked_all(land_mask.shape)
             new_data.fill_value = mdi
@@ -1476,8 +1475,18 @@ class PPField2(PPField):
 
         """
         if not hasattr(self, "_t1"):
+            has_year_zero = self.lbyr == 0
+            calendar = (
+                None if self.lbmon == 0 or self.lbdat == 0 else self.calendar
+            )
             self._t1 = cftime.datetime(
-                self.lbyr, self.lbmon, self.lbdat, self.lbhr, self.lbmin
+                self.lbyr,
+                self.lbmon,
+                self.lbdat,
+                self.lbhr,
+                self.lbmin,
+                calendar=calendar,
+                has_year_zero=has_year_zero,
             )
         return self._t1
 
@@ -1500,8 +1509,18 @@ class PPField2(PPField):
 
         """
         if not hasattr(self, "_t2"):
+            has_year_zero = self.lbyrd == 0
+            calendar = (
+                None if self.lbmond == 0 or self.lbdatd == 0 else self.calendar
+            )
             self._t2 = cftime.datetime(
-                self.lbyrd, self.lbmond, self.lbdatd, self.lbhrd, self.lbmind
+                self.lbyrd,
+                self.lbmond,
+                self.lbdatd,
+                self.lbhrd,
+                self.lbmind,
+                calendar=calendar,
+                has_year_zero=has_year_zero,
             )
         return self._t2
 
@@ -1537,6 +1556,10 @@ class PPField3(PPField):
 
         """
         if not hasattr(self, "_t1"):
+            has_year_zero = self.lbyr == 0
+            calendar = (
+                None if self.lbmon == 0 or self.lbdat == 0 else self.calendar
+            )
             self._t1 = cftime.datetime(
                 self.lbyr,
                 self.lbmon,
@@ -1544,6 +1567,8 @@ class PPField3(PPField):
                 self.lbhr,
                 self.lbmin,
                 self.lbsec,
+                calendar=calendar,
+                has_year_zero=has_year_zero,
             )
         return self._t1
 
@@ -1566,6 +1591,10 @@ class PPField3(PPField):
 
         """
         if not hasattr(self, "_t2"):
+            has_year_zero = self.lbyrd == 0
+            calendar = (
+                None if self.lbmond == 0 or self.lbdatd == 0 else self.calendar
+            )
             self._t2 = cftime.datetime(
                 self.lbyrd,
                 self.lbmond,
@@ -1573,6 +1602,8 @@ class PPField3(PPField):
                 self.lbhrd,
                 self.lbmind,
                 self.lbsecd,
+                calendar=calendar,
+                has_year_zero=has_year_zero,
             )
         return self._t2
 
