@@ -273,10 +273,16 @@ class TestLazySave(tests.IrisTest):
         )
         acube = iris.load_cube(fpath, "air_temperature")
         self.assertTrue(acube.has_lazy_data())
+        # Also check a coord with lazy points + bounds.
+        self.assertTrue(acube.coord("forecast_period").has_lazy_points())
+        self.assertTrue(acube.coord("forecast_period").has_lazy_bounds())
         with self.temp_filename(".nc") as nc_path:
             with Saver(nc_path, "NETCDF4") as saver:
                 saver.write(acube)
+        # Check that cube data is not realised, also coord points + bounds.
         self.assertTrue(acube.has_lazy_data())
+        self.assertTrue(acube.coord("forecast_period").has_lazy_points())
+        self.assertTrue(acube.coord("forecast_period").has_lazy_bounds())
 
 
 @tests.skip_data
@@ -707,6 +713,7 @@ data:
         self.assertEqual(cs.false_northing, 0.0)
 
 
+@tests.skip_data
 class TestConstrainedLoad(tests.IrisTest):
     filename = tests.get_data_path(
         ("NetCDF", "label_and_climate", "A1B-99999a-river-sep-2070-2099.nc")
