@@ -6,11 +6,12 @@
 
 # import iris tests first so that some things can be initialised before
 # importing anything else
-import iris.tests as tests
+import iris.tests as tests  # isort:skip
+
+import unittest
 
 import numpy as np
 import numpy.ma as ma
-import unittest
 
 import iris
 import iris.analysis
