@@ -6,7 +6,7 @@
 
 
 # import iris tests first so that some things can be initialised before importing anything else
-import iris.tests as tests
+import iris.tests as tests  # isort:skip
 
 import cf_units
 import numpy as np
