@@ -11,7 +11,7 @@ Unit tests for the
 
 # Import iris.tests first so that some things can be initialised before
 # importing anything else.
-import iris.tests as tests
+import iris.tests as tests  # isort:skip
 
 from unittest import mock
 
@@ -199,22 +199,22 @@ class Test_make_coord(tests.IrisTest):
 
     def setUp(self):
         self.sigma = DimCoord(
-            np.arange(5, dtype=np.float) * 10, long_name="sigma", units="1"
+            np.arange(5, dtype=np.float64) * 10, long_name="sigma", units="1"
         )
         self.eta = AuxCoord(
-            np.arange(4, dtype=np.float).reshape(2, 2),
+            np.arange(4, dtype=np.float64).reshape(2, 2),
             long_name="eta",
             units="m",
         )
         self.depth = AuxCoord(
-            np.arange(4, dtype=np.float).reshape(2, 2) * 10,
+            np.arange(4, dtype=np.float64).reshape(2, 2) * 10,
             long_name="depth",
             units="m",
         )
         self.depth_c = AuxCoord([15], long_name="depth_c", units="m")
         self.nsigma = AuxCoord([3], long_name="nsigma")
         self.zlev = DimCoord(
-            np.arange(5, dtype=np.float) * 10, long_name="zlev", units="m"
+            np.arange(5, dtype=np.float64) * 10, long_name="zlev", units="m"
         )
         self.kwargs = dict(
             sigma=self.sigma,
