@@ -11,13 +11,13 @@ Unit tests for
 
 # Import iris.tests first so that some things can be initialised before
 # importing anything else.
-import iris.tests as tests
+import iris.tests as tests  # isort:skip
 
 import numpy as np
 
-from iris.coords import DimCoord, AuxCoord
-from iris.aux_factory import HybridPressureFactory, HybridHeightFactory
-from iris.fileformats.pp import SplittableInt, STASH
+from iris.aux_factory import HybridHeightFactory, HybridPressureFactory
+from iris.coords import AuxCoord, DimCoord
+from iris.fileformats.pp import STASH, SplittableInt
 from iris.fileformats.pp_load_rules import Reference, _convert_vertical_coords
 from iris.tests.unit.fileformats import TestField
 
