@@ -7,7 +7,7 @@
 
 # Import iris.tests first so that some things can be initialised before
 # importing anything else.
-import iris.tests as tests
+import iris.tests as tests  # isort:skip
 
 import iris.coords
 from iris.tests.stock import simple_2d, simple_2d_w_multidim_coords
